Module: DoDelegate

Extended by:
ActiveSupport::Concern
Included in:
ActiveRecord::Migration::Ext::DelegateToConnection
Defined in:
lib/active_record/migration/ext/delegate_to_connection.rb

Overview

Provides an alternate alias for delegate in case the one we want from Module is shadowed.

Normally, you could just call delegate directly, but Migration defines this at class level, which shadows the delegate method from Module: attr_accessor :delegate

Defined Under Namespace

Modules: ClassMethods